        function getT(rr,cc){
       if(rr==1 && cc==0){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260810 a 12</strong> UTC HH+168 (rango:156-180)<br><strong>control +<br>EPS</strong>';}
       if(rr==1 && cc==1){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260810 a 12</strong> UTC HH+168 (rango:156-180)<br>grupo: <strong>1</strong> representante: <strong>13</strong> miembros: 24 <strong>control</strong><br>0,1,3,12,13,17,19,20,21,22,23,25,26,29,33,35,36,39,41,42,43,45,47,50';}
       if(rr==1 && cc==2){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260810 a 12</strong> UTC HH+168 (rango:156-180)<br>grupo: <strong>2</strong> representante: <strong>28</strong> miembros: 14 <br>2,6,8,14,24,28,30,31,34,38,40,44,46,49';}
       if(rr==1 && cc==3){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260810 a 12</strong> UTC HH+168 (rango:156-180)<br>grupo: <strong>3</strong> representante: <strong>11</strong> miembros: 13 <br>4,5,7,9,10,11,15,16,18,27,32,37,48';}
       if(rr==8 && cc==0){return '<strong>Temperatura en 850 hPa (C) y Presion en Superficie (hPa)</strong><br><br><strong>20260810 a 12</strong> UTC HH+168 (rango:156-180)<br><strong>control +<br>EPS</strong>';}
       if(rr==8 && cc==1){return '<strong>Temperatura en 850 hPa (C) y Presion en Superficie (hPa)</strong><br><br><strong>20260810 a 12</strong> UTC HH+168 (rango:156-180)<br>grupo: <strong>1</strong> representante: <strong>13</strong> miembros: 24 <strong>control</strong><br>0,1,3,12,13,17,19,20,21,22,23,25,26,29,33,35,36,39,41,42,43,45,47,50';}
       if(rr==8 && cc==2){return '<strong>Temperatura en 850 hPa (C) y Presion en Superficie (hPa)</strong><br><br><strong>20260810 a 12</strong> UTC HH+168 (rango:156-180)<br>grupo: <strong>2</strong> representante: <strong>28</strong> miembros: 14 <br>2,6,8,14,24,28,30,31,34,38,40,44,46,49';}
       if(rr==8 && cc==3){return '<strong>Temperatura en 850 hPa (C) y Presion en Superficie (hPa)</strong><br><br><strong>20260810 a 12</strong> UTC HH+168 (rango:156-180)<br>grupo: <strong>3</strong> representante: <strong>11</strong> miembros: 13 <br>4,5,7,9,10,11,15,16,18,27,32,37,48';}
       if(rr==18 && cc==0){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 1 mm</strong><br><br><strong>20260810 a 12</strong> UTC HH+168 (rango:156-180)<br><strong>control +<br>EPS</strong>';}
       if(rr==18 && cc==1){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 1 mm</strong><br><br><strong>20260810 a 12</strong> UTC HH+168 (rango:156-180)<br>grupo: <strong>1</strong> representante: <strong>13</strong> miembros: 24 <strong>control</strong><br>0,1,3,12,13,17,19,20,21,22,23,25,26,29,33,35,36,39,41,42,43,45,47,50';}
       if(rr==18 && cc==2){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 1 mm</strong><br><br><strong>20260810 a 12</strong> UTC HH+168 (rango:156-180)<br>grupo: <strong>2</strong> representante: <strong>28</strong> miembros: 14 <br>2,6,8,14,24,28,30,31,34,38,40,44,46,49';}
       if(rr==18 && cc==3){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 1 mm</strong><br><br><strong>20260810 a 12</strong> UTC HH+168 (rango:156-180)<br>grupo: <strong>3</strong> representante: <strong>11</strong> miembros: 13 <br>4,5,7,9,10,11,15,16,18,27,32,37,48';}
       if(rr==24 && cc==0){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 1 mm de agua equivalente</strong><br><br><strong>20260810 a 12</strong> UTC HH+168 (rango:156-180)<br><strong>control +<br>EPS</strong>';}
       if(rr==24 && cc==1){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 1 mm de agua equivalente</strong><br><br><strong>20260810 a 12</strong> UTC HH+168 (rango:156-180)<br>grupo: <strong>1</strong> representante: <strong>13</strong> miembros: 24 <strong>control</strong><br>0,1,3,12,13,17,19,20,21,22,23,25,26,29,33,35,36,39,41,42,43,45,47,50';}
       if(rr==24 && cc==2){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 1 mm de agua equivalente</strong><br><br><strong>20260810 a 12</strong> UTC HH+168 (rango:156-180)<br>grupo: <strong>2</strong> representante: <strong>28</strong> miembros: 14 <br>2,6,8,14,24,28,30,31,34,38,40,44,46,49';}
       if(rr==24 && cc==3){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 1 mm de agua equivalente</strong><br><br><strong>20260810 a 12</strong> UTC HH+168 (rango:156-180)<br>grupo: <strong>3</strong> representante: <strong>11</strong> miembros: 13 <br>4,5,7,9,10,11,15,16,18,27,32,37,48';}
       if(rr==44 && cc==0){return '<strong>Desviacion estandar e isohipsas de altura geopotencial (m) en 500 hPa</strong><br><br><strong>20260810 a 12</strong> UTC HH+168 (rango:156-180)<br><strong>control +<br>EPS</strong>';}
       if(rr==44 && cc==1){return '<strong>Desviacion estandar e isohipsas de altura geopotencial (m) en 500 hPa</strong><br><br><strong>20260810 a 12</strong> UTC HH+168 (rango:156-180)<br>grupo: <strong>1</strong> representante: <strong>13</strong> miembros: 24 <strong>control</strong><br>0,1,3,12,13,17,19,20,21,22,23,25,26,29,33,35,36,39,41,42,43,45,47,50';}
       if(rr==44 && cc==2){return '<strong>Desviacion estandar e isohipsas de altura geopotencial (m) en 500 hPa</strong><br><br><strong>20260810 a 12</strong> UTC HH+168 (rango:156-180)<br>grupo: <strong>2</strong> representante: <strong>28</strong> miembros: 14 <br>2,6,8,14,24,28,30,31,34,38,40,44,46,49';}
       if(rr==44 && cc==3){return '<strong>Desviacion estandar e isohipsas de altura geopotencial (m) en 500 hPa</strong><br><br><strong>20260810 a 12</strong> UTC HH+168 (rango:156-180)<br>grupo: <strong>3</strong> representante: <strong>11</strong> miembros: 13 <br>4,5,7,9,10,11,15,16,18,27,32,37,48';}
       if(rr==45 && cc==0){return '<strong>Spaguetti de presion en superficie (hPa)</strong><br><br><strong>20260810 a 12</strong> UTC HH+168 (rango:156-180)<br><strong>control +<br>EPS</strong>';}
       if(rr==45 && cc==1){return '<strong>Spaguetti de presion en superficie (hPa)</strong><br><br><strong>20260810 a 12</strong> UTC HH+168 (rango:156-180)<br>grupo: <strong>1</strong> representante: <strong>13</strong> miembros: 24 <strong>control</strong><br>0,1,3,12,13,17,19,20,21,22,23,25,26,29,33,35,36,39,41,42,43,45,47,50';}
       if(rr==45 && cc==2){return '<strong>Spaguetti de presion en superficie (hPa)</strong><br><br><strong>20260810 a 12</strong> UTC HH+168 (rango:156-180)<br>grupo: <strong>2</strong> representante: <strong>28</strong> miembros: 14 <br>2,6,8,14,24,28,30,31,34,38,40,44,46,49';}
       if(rr==45 && cc==3){return '<strong>Spaguetti de presion en superficie (hPa)</strong><br><br><strong>20260810 a 12</strong> UTC HH+168 (rango:156-180)<br>grupo: <strong>3</strong> representante: <strong>11</strong> miembros: 13 <br>4,5,7,9,10,11,15,16,18,27,32,37,48';}
}
